yakumo.nova.v2.fixed_ip

Package yakumo :: Package nova :: Package v2 :: Module fixed_ip |
[hide private]
[frames] | no frames]

# Module fixed_ip

source code

Resource class and its manager for fixed IPs in Compute API v2

Classes | [hide private]
| Resource Resource class for fixed IPs in Compute API v2
| Manager Manager class for fixed IPs in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``ip``'``,` `'````'``,` <yakumo.mapper.NoopClass objec`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('ip', '', <yakumo.mapper.NoopClass object at 0x7f133076f290>)]